# Jupyter Community Call May 31

**Date:** May 31, 2022, at 7am Pacific (in your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-05-31/7:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)**

**[YouTube link](https://youtu.be/KzH7yJ07PgQ)** 

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Isabela:** Shout out to the security team for rolling out awesome documentation on the [Jupyter Vulnerability Handling Process](https://github.com/jupyter/security/blob/main/docs/vulnerability-handling.md#roles)!
    
* **Isabela:** Reminder that the [Jupyter Community Workshops call for proposals](https://blog.jupyter.org/jupyter-community-workshops-c7491a3cca00) has been extended! You can now apply until June 6.

* **Mike** Organising an internal intermediate/advanced jupyter training at Oxford, anything cool you would like to to share with biomedical researchers?
    * Matthias: I would search a bit on the napari side. 
    * Chris Holdgraf is in Europe and runs [2i2c](https://2i2c.org/), he might be a good person to ask. 
    * Romeo: reach out about relevant talks
        * Deep Learning in biomedical and genomics data
            * ...using JuypterLab
            * ...using Elyra Pipelines
        * Deep Learning based image analysis in Radiology
        * An overview and life demo of JupyterLab Extensions for Genomics
        * An overview and life demo of JupyterLab Extensions for Life Science
* [Please don’t disable authentication in Jupyter servers- Jupyter blog](https://blog.jupyter.org/please-dont-disable-authentication-in-jupyter-servers-dd197206e7f6)

* **Matthias**: SciPy draft done! Hooray!
* **Gayle**: Shout out to Sylvain for speaking at the upcoming [PyData London](https://pydata.org/london2022/)

## Agenda Items

Add agenda items here **before** the meeting. We will reorganize the agenda so that it fits in the 60m meeting slot.

* **Name** This is an example of agenda item formatting.

* **Matthias** And https://github.com/jupyter/jupyter.github.io/pull/696, we'd love to know if some folks want to participate / help handle the process – no need to be be a security expert.
* **Matthias** Question : Anything to organise about SciPy ? 
    * Gayle: there is interest in organizing, but we need ideas! Reach out if there's something you'd like to organize.
    * Isabela: not aware of anything that has developed yet, but can ask around.
* **Isabela** Sharing two cool resources I don't see talked about often:
    * [jupyter/surveys](https://github.com/jupyter/surveys)
    * [JupyterLab user stories](https://github.com/jupyterlab/jupyterlab/tree/master/design)

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- A curated list of awesome Jupyter projects, libraries and resources at [markusschanta/awesome-jupyter](https://github.com/markusschanta/awesome-jupyter)
- A curated list of awesome JupyterLab extensions and resources at [mauhai/awesome-jupyterlab](https://github.com/mauhai/awesome-jupyterlab)

## Attendees

|   Name   |           Institution     | GitHub Handle|
|----------|---------------------------|--------------|
| Wayne Decatur  | Upstate Medical University  | @fomightez 
| Michał Krassowski | Oxford            | @krassowski
| Gayle Ollington|NumFOCUS|@gollington         |            | 
| Eric Gentry | Anaconda | @ericsnekbytes |
| Romeo Kienzler | IBM (CODAIT) | @romeokienzler |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |

Plus one more.